==============
Special Thanks
==============

A lot of free services and open source libraries have helped this project become possible. This page aims to give credit where its due; if you were left out, I'm sorry! Please let me know!

Contributors
------------

Thank you to the following people who generously contributed their time and brainpower towards writing code that was merged into the library.

    * `Thomas Applencourt`_
    * `Florian Kromer`_

Services
--------

Thank you to the free hosting provided by these services!

    * `GitHub`_
    * `Travis CI`_
    * `AppVeyor`_
    * `Read the Docs`_


Design Resources
----------------

Thank you to Matthew Beckler, who designed the `logic gate SVGs`_ present in tt's logo.


Third Party Libraries Shipped with tt
-------------------------------------

Thank you to the developers of the following third party libraries that are wrapped in and shipped with tt. Your hard work drives some of the most powerful functionality of tt.

    * `PicoSAT`_


Inspiration
-----------

Thanks goes to the developers of the `PyEDA`_ and `pycosat`_ libraries, whose interface and design are inspirations behind a lot of the functionality packed in tt.


Open Source Projects & Libraries
--------------------------------

tt relies on some well-written and well-documented projects and libraries for its development, listed below. Thank you!

    * `Alabaster`_
    * `Babel`_
    * `Colorama`_
    * `Docutils`_
    * `Flake8`_
    * `imagesize`_
    * `Jinja2`_
    * `MarkupSafe`_
    * `McCabe`_
    * `pep8`_
    * `pluggy`_
    * `py`_
    * `pyenv`_
    * `pyflakes`_
    * `Pygments`_
    * `Python`_
    * `pytz`_
    * `Requests`_
    * `six`_
    * `snowballstemmer`_
    * `Sphinx`_
    * `tox`_
    * `twine`_
    * `virtualenv`_

.. _Thomas Applencourt: https://github.com/TApplencourt
.. _Florian Kromer: https://github.com/fkromer

.. _GitHub: https://github.com/
.. _Travis CI: https://travis-ci.org/
.. _AppVeyor: https://www.appveyor.com/
.. _Read the Docs: https://readthedocs.org/

.. _logic gate SVGs: https://www.mbeckler.org/inkscape/drawings/

.. _PicoSAT: http://fmv.jku.at/picosat/

.. _PyEDA: https://github.com/cjdrake/pyeda
.. _pycosat: https://github.com/ContinuumIO/pycosat

.. _Alabaster: http://alabaster.readthedocs.io/en/latest/
.. _Babel: http://babel.pocoo.org/en/latest/
.. _Colorama: https://github.com/tartley/colorama
.. _Docutils: http://docutils.sourceforge.net/
.. _Flake8: http://flake8.pycqa.org/en/latest/
.. _imagesize: https://github.com/shibukawa/imagesize_py
.. _Jinja2: http://jinja.pocoo.org/docs/dev/
.. _MarkupSafe: http://www.pocoo.org/projects/markupsafe/
.. _McCabe: https://github.com/pycqa/mccabe
.. _pep8: http://pep8.readthedocs.io/
.. _pluggy: https://github.com/pytest-dev/pluggy
.. _py: https://github.com/pytest-dev/py
.. _pyenv: https://github.com/pyenv/pyenv
.. _pyflakes: https://github.com/PyCQA/pyflakes
.. _Pygments: http://pygments.org/
.. _Python: https://www.python.org/
.. _pytz: https://pypi.python.org/pypi/pytz/
.. _Requests: http://docs.python-requests.org/en/master/
.. _six: https://pythonhosted.org/six/
.. _snowballstemmer: https://github.com/shibukawa/snowball_py
.. _Sphinx: http://www.sphinx-doc.org/en/latest/
.. _tox: https://tox.readthedocs.io/en/latest/
.. _twine: https://github.com/pypa/twine
.. _virtualenv: https://virtualenv.pypa.io/en/stable/
